#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-api-data
version:              0.6.1
visibility:           public
id:                   http-api-data-0.6.1-6rhAeoExtmSLOw1wQVhqdJ
key:                  http-api-data-0.6.1-6rhAeoExtmSLOw1wQVhqdJ
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  94c6b3c23455aef9ea3cc562789543e1
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.6.1-6rhAeoExtmSLOw1wQVhqdJ
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    hashable-1.4.7.0-LnVJu1JSZWR8SeekGz9T3N
    http-types-0.12.4-J4f9RYTa0ze5zkpv7SJ8lm
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    text-iso8601-0.1.1.1-H9BOSZGc5sS2g1sxwhSOYS
    time-compat-1.9.9-BwD837haGen4Ab8AkszbXA transformers-0.6.1.0
    unordered-containers-0.2.20.1-9MqMq77Kwyw3AYghIevUCW
    uuid-types-1.0.6.1-K9KQKWWgQSnClE1IrDqE3m

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

